@@ -1,5 +1,5 @@
 #
-# Copyright © 2012 - 2020 Michal Čihař <michal@cihar.com>
+# Copyright © 2012 - 2021 Michal Čihař <michal@cihar.com>
 #
 # This file is part of Weblate translation-finder
 # <https://github.com/WeblateOrg/translation-finder>
@@ -36,6 +36,7 @@ from .discovery.files import (
     OSXDiscovery,
     PHPDiscovery,
     QtDiscovery,
+    RCDiscovery,
     RESXDiscovery,
     TOMLDiscovery,
     WebExtensionDiscovery,
@@ -1167,3 +1168,25 @@ class PHPDiscoveryTest(DiscoveryTestCase):
                 },
             ],
         )
+
+
+class TestRCDiscovery(DiscoveryTestCase):
+    def test_basic(self):
+        discovery = RCDiscovery(self.get_finder(["test_enu.rc", "other_ENU.rc"]))
+        self.assert_discovery(
+            discovery.discover(),
+            [
+                {
+                    "filemask": "test_*.rc",
+                    "file_format": "rc",
+                    "template": "test_enu.rc",
+                    "new_base": "test_enu.rc",
+                },
+                {
+                    "filemask": "other_*.rc",
+                    "file_format": "rc",
+                    "template": "other_ENU.rc",
+                    "new_base": "other_ENU.rc",
+                },
+            ],
+        )
